@@ -2,7 +2,8 @@ package ExtUtils::Typemaps;
 use 5.006001;
 use strict;
 use warnings;
-our $VERSION = '3.43_02';
+our $VERSION = '1.01';
+#use Carp qw(croak);
 
 require ExtUtils::ParseXS;
 require ExtUtils::ParseXS::Constants;
@@ -22,7 +23,7 @@ ExtUtils::Typemaps - Read/Write/Modify Perl/XS typemap files
   # $typemap = ExtUtils::Typemaps->new();
   # alternatively create an in-memory typemap by parsing a string
   # $typemap = ExtUtils::Typemaps->new(string => $sometypemap);
-
+  
   # add a mapping
   $typemap->add_typemap(ctype => 'NV', xstype => 'T_NV');
   $typemap->add_inputmap(
@@ -33,13 +34,13 @@ ExtUtils::Typemaps - Read/Write/Modify Perl/XS typemap files
   );
   $typemap->add_string(string => $typemapstring);
                                            # will be parsed and merged
-
+  
   # remove a mapping (same for remove_typemap and remove_outputmap...)
   $typemap->remove_inputmap(xstype => 'SomeType');
-
+  
   # save a typemap to a file
   $typemap->write(file => 'anotherfile.map');
-
+  
   # merge the other typemap into this one
   $typemap->merge(typemap => $another_typemap);
 
@@ -110,7 +111,6 @@ sub _init {
   }
 }
 
-
 =head2 file
 
 Get/set the file that the typemap is written to when the
@@ -344,7 +344,7 @@ sub remove_typemap {
     my %args = @_;
     $ctype = $args{ctype};
     die("Need ctype argument") if not defined $ctype;
-    $ctype = tidy_type($ctype);
+    $ctype = _tidy_type($ctype);
   }
   else {
     $ctype = $_[0]->tidy_ctype;
@@ -443,7 +443,7 @@ sub get_typemap {
   my %args = @_;
   my $ctype = $args{ctype};
   die("Need ctype argument") if not defined $ctype;
-  $ctype = tidy_type($ctype);
+  $ctype = _tidy_type($ctype);
 
   my $index = $self->{typemap_lookup}{$ctype};
   return() if not defined $index;
@@ -536,7 +536,7 @@ sub get_outputmap {
 
 Write the typemap to a file. Optionally takes a C<file> argument. If given, the
 typemap will be written to the specified file. If not, the typemap is written
-to the currently stored file name (see L</file> above, this defaults to the file
+to the currently stored file name (see C<-E<gt>file> above, this defaults to the file
 it was read from if any).
 
 =cut
@@ -590,40 +590,6 @@ sub as_string {
   return join '', @code;
 }
 
-=head2 as_embedded_typemap
-
-Generates and returns the string form of the typemap with the
-appropriate prefix around it for verbatim inclusion into an
-XS file as an embedded typemap. This will return a string like
-
-  TYPEMAP: <<END_OF_TYPEMAP
-  ... typemap here (see as_string) ...
-  END_OF_TYPEMAP
-
-The method takes care not to use a HERE-doc end marker that
-appears in the typemap string itself.
-
-=cut
-
-sub as_embedded_typemap {
-  my $self = shift;
-  my $string = $self->as_string;
-
-  my @ident_cand = qw(END_TYPEMAP END_OF_TYPEMAP END);
-  my $icand = 0;
-  my $cand_suffix = "";
-  while ($string =~ /^\Q$ident_cand[$icand]$cand_suffix\E\s*$/m) {
-    $icand++;
-    if ($icand == @ident_cand) {
-      $icand = 0;
-      ++$cand_suffix;
-    }
-  }
-
-  my $marker = "$ident_cand[$icand]$cand_suffix";
-  return "TYPEMAP: <<$marker;\n$string\n$marker\n";
-}
-
 =head2 merge
 
 Merges a given typemap into the object. Note that a failed merge
@@ -688,18 +654,6 @@ sub is_empty {
       && @{ $self->{output_section} } == 0;
 }
 
-=head2 list_mapped_ctypes
-
-Returns a list of the C types that are mappable by
-this typemap object.
-
-=cut
-
-sub list_mapped_ctypes {
-  my $self = shift;
-  return sort keys %{ $self->{typemap_lookup} };
-}
-
 =head2 _get_typemap_hash
 
 Returns a hash mapping the C types to the XS types:
@@ -781,9 +735,7 @@ corresponding OUTPUT code:
                 $var.context.value().size());
   ',
     'T_OUT' => '    {
-            GV *gv = (GV *)sv_newmortal();
-            gv_init_pvn(gv, gv_stashpvs("$Package",1),
-                       "__ANONIO__",10,0);
+            GV *gv = newGVgen("$Package");
             if ( do_open(gv, "+>&", 3, FALSE, 0, 0, $var) )
                 sv_setsv(
                   $arg,
@@ -862,7 +814,7 @@ sub validate {
   my %args = @_;
 
   if ( exists $args{ctype}
-       and exists $self->{typemap_lookup}{tidy_type($args{ctype})} )
+       and exists $self->{typemap_lookup}{_tidy_type($args{ctype})} )
   {
     die("Multiple definition of ctype '$args{ctype}' in TYPEMAP section");
   }
@@ -882,84 +834,6 @@ sub validate {
   return 1;
 }
 
-=head2 clone
-
-Creates and returns a clone of a full typemaps object.
-
-Takes named parameters: If C<shallow> is true,
-the clone will share the actual individual type/input/outputmap objects,
-but not share their storage. Use with caution. Without C<shallow>,
-the clone will be fully independent.
-
-=cut
-
-sub clone {
-  my $proto = shift;
-  my %args = @_;
-
-  my $self;
-  if ($args{shallow}) {
-    $self = bless( {
-      %$proto,
-      typemap_section => [@{$proto->{typemap_section}}],
-      typemap_lookup  => {%{$proto->{typemap_lookup}}},
-      input_section   => [@{$proto->{input_section}}],
-      input_lookup    => {%{$proto->{input_lookup}}},
-      output_section  => [@{$proto->{output_section}}],
-      output_lookup   => {%{$proto->{output_lookup}}},
-    } => ref($proto) );
-  }
-  else {
-    $self = bless( {
-      %$proto,
-      typemap_section => [map $_->new, @{$proto->{typemap_section}}],
-      typemap_lookup  => {%{$proto->{typemap_lookup}}},
-      input_section   => [map $_->new, @{$proto->{input_section}}],
-      input_lookup    => {%{$proto->{input_lookup}}},
-      output_section  => [map $_->new, @{$proto->{output_section}}],
-      output_lookup   => {%{$proto->{output_lookup}}},
-    } => ref($proto) );
-  }
-
-  return $self;
-}
-
-=head2 tidy_type
-
-Function to (heuristically) canonicalize a C type. Works to some
-degree with C++ types.
-
-    $halfway_canonical_type = tidy_type($ctype);
-
-Moved from C<ExtUtils::ParseXS>.
-
-=cut
-
-sub tidy_type {
-  local $_ = shift;
-
-  # for templated C++ types, do some bit of flawed canonicalization
-  # wrt. templates at least
-  if (/[<>]/) {
-    s/\s*([<>])\s*/$1/g;
-    s/>>/> >/g;
-  }
-
-  # rationalise any '*' by joining them into bunches and removing whitespace
-  s#\s*(\*+)\s*#$1#g;
-  s#(\*+)# $1 #g ;
-
-  # trim leading & trailing whitespace
-  s/^\s+//; s/\s+$//;
-
-  # change multiple whitespace into a single space
-  s/\s+/ /g;
-
-  $_;
-}
-
-
-
 sub _parse {
   my $self = shift;
   my $stringref = shift;
@@ -1049,6 +923,24 @@ sub _parse {
   return 1;
 }
 
+# taken from ExtUtils::ParseXS
+sub _tidy_type {
+  local $_ = shift;
+
+  # rationalise any '*' by joining them into bunches and removing whitespace
+  s#\s*(\*+)\s*#$1#g;
+  s#(\*+)# $1 #g ;
+
+  # trim leading & trailing whitespace
+  s/^\s+//; s/\s+$//;
+
+  # change multiple whitespace into a single space
+  s/\s+/ /g;
+
+  $_;
+}
+
+
 # taken from ExtUtils::ParseXS
 sub _valid_proto_string {
   my $string = shift;
@@ -1082,7 +974,7 @@ Steffen Mueller C<<smueller@cpan.org>>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009, 2010, 2011, 2012, 2013 Steffen Mueller
+Copyright 2009-2011 Steffen Mueller
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
